==> cpg1.4.x_plugin_jupload_v3.5.1.zip: jupload/page/ajax_list_album_of_a_category.php <==
<?php
/*
 *******************************************
 plugin JUpload for Coppermine Photo Gallery
 *******************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 ********************************************
 $Revision: 185 $
 $Author: etienne_sf $
 $Date: 2008-03-12 20:26:16 +0100 (mer., 12 mars 2008) $
 ********************************************
 *
 * Allows easy upload to the gallery, through a java applet. 
 * 
 * Up to date version of this script can be retrieved with the full JUpload package, here:
 * 
 * http://etienne.sf.free.fr/wiki
 * 
 * Directly here:
 * http://etienne.sf.free.fr/wiki/doku.php?id=jupload_coppermine_download_gb
 * 
 * Support is available on this forum:
 * http://coppermine-gallery.net/forum/index.php?topic=43432
 * 
 * The applet is published on sourceforge:
 * http://jupload.sourceforge.net
 * 
 */


if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}
if (!defined('JUPLOAD_PHP')) { die('Not in Jupload...');}

require_once('plugins/jupload/include/j_catmgr.inc.php');



	//We clear the current output, as the output of this script will contain only some javascript commands.
	ob_end_clean();
	header('Content-Type: text/plain; charset="UTF-8');
	ob_start();  //Flush is done by jupload.php	
	
	//The line below is for debug only.
	if (isDebugActive()) {	
		echo("alert('category used: $category');\n");
	}	
	echo("document.form_album.category.value=$category;\n");


	jsFillAlbumList($category);

==> cpg1.5.x_plugin_jupload_v4.0.0_rc3.zip: jupload/page/ajax_list_album_of_a_category.php <==
<?php
/*
 *******************************************
 plugin JUpload for Coppermine Photo Gallery
 *******************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 ********************************************
 $Revision: 185 $
 $Author: etienne_sf $
 $Date: 2008-03-12 20:26:16 +0100 (mer., 12 mars 2008) $
 ********************************************
 *
 * Allows easy upload to the gallery, through a java applet. 
 * 
 * Up to date version of this script can be retrieved with the full JUpload package, here:
 * 
 * http://etienne.sf.free.fr/wiki
 * 
 * Directly here:
 * http://forum.coppermine-gallery.net/index.php/board,100.0.html
 * 
 * Support is available on this forum:
 * http://coppermine-gallery.net/forum/index.php?topic=43432
 * 
 * The applet is published on sourceforge:
 * http://jupload.sourceforge.net
 * 
 */


if (!defined('IN_COPPERMINE')) { die('alert("Not in Coppermine...");');}
if (!defined('JUPLOAD_PHP')) { die('alert("Not in Jupload...");');}

logDebug('alert("before include of j_catmgr.inc.php");');
require_once('plugins/jupload/include/j_catmgr.inc.php');
logDebug('after include of j_catmgr.inc.php');



	//We clear the current output, as the output of this script will contain only some javascript commands.
	ob_end_clean();
	header('Content-Type: text/plain; charset="UTF-8');
	ob_start();  //Flush is done by jupload.php	
	
	//The line below is for debug only.
	if (isDebugActive()) {	
		echo("alert('category used: $category');\n");
	}	
	echo("document.form_album.category.value=$category;\n");


	jsFillAlbumList($category);
